# Diese beiden Module sollten immer und immer in dieser Reihenfolge
# geladen werden:

use Gimp;
use Gimp::Fu;

Gimp::set_trace(TRACE_NAME);

# Definiere die Konstante "pi mal zwei"
use constant PIx2 => 8 * atan2 1,1;

register "random_art",				# Funktionsname
         "Creates a Random Image",		# Kurzhilfe
         "Create an image by repeatedly drawing colourful polygones.",
         					# Hilfetext
         "Marc Lehmann",			# Autor
         "Marc Lehmann <pcg\@goof.com",		# Copyright
         "0.2",					# Version/Datum
         "<Toolbox>/Xtns/Render/Random Art",	# Menpfad
         "",					# Bildtypen
         # Eingabeparameter
         # Typ		Name		Beschreibung		Wert
         [
          [PF_INT32,	'size',		'Image Size',	 	300],
          [PF_INT32,	'num_poly',	'Number of Polygons', 	20],
         ],
         sub {					# Perl-Code
   # Die Parameter werden ganz "normal" bergeben:
   my ($size,$num_poly)=@_;

   # Erzeuge ein neues Bild
   my $image = new Image($size,$size,RGB);

   # Erzeuge die erste Ebene fr das Bild
   my $layer = $image->layer_new($size,$size,RGBA_IMAGE,
                   "Random Art",100,NORMAL_MODE);

   # Fge sie in das Bild ein
   $image->add_layer($layer,0);

   # Setze die Hintergrundfarben
   Palette->set_background('white');

   # ...und lsche die Ebene damit
   $layer->fill(BG_IMAGE_FILL);

   # Jetzt wurde ein neues, leeres Bild erzeugt, und
   # das Zeichnen kann beginnen.

   # Erzeuge zufllige Polygone, flle sie mit einem
   # zuflligen Farbgradienten und verschiebe das Bild
   # wiederholt.
   for (1..$num_poly) {
      # Erzeuge ein sich nicht berschneidendes Polygon
      # mit 10 Eckpunkten.
      my @ecken;
      for (0..9) {
         my $r = rand($size*0.4)+$size*0.1;
         push(@ecken, $size/2+sin($_*PIx2/10)*$r,
                      $size/2+cos($_*PIx2/10)*$r);
      }

      # Selektiere die Region
      $image->free_select (\@ecken, SELECTION_REPLACE, 1, 1, 30);

      # Whle zufllig zwei Farben aus
      Palette->set_foreground([rand(256),rand(256),rand(256)]);
      Palette->set_background([rand(256),rand(256),rand(256)]);
      
      # Un erzeuge einen Farbverlauf ber das Bild
      $layer->blend (FG_BG_HSV, DIFFERENCE_MODE, LINEAR, 100,
                     0, REPEAT_TRIANGULAR, 1, 2, 3,
                     $size/2, $size/2,
                     rand($size*0.6), rand($size*0.6));
      
      # Und dann verschiebe das Bild etwas
      $layer->channel_ops_offset (1,0,rand($size),rand($size));
   }

   # Gib das neu erzeugte Bild zurck, damit es angezeigt wird.
   $image;
};

exit main;

